@@ -8,7 +8,7 @@
 #######################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '0.4-1'
+Version = '1.0-1'
 
 import os
 import sys
@@ -59,25 +59,59 @@ def showQuickMessage(message):
                org.freedesktop.Notifications.SystemNoteInfoprint \
                string:"%s"' % message)          
 
-###########################################################
+def CheckConfigFile():
+     ''' Check for configulation files. '''               
 
-''' Check for configulation files. '''               
-if CheckFile(PathTheme,ConfigTheme) == True:
-     Path = PathTheme
-     Config = ConfigTheme
-     message = 'INFO: Reading the CURRENT configuration from the theme folder..'
-elif CheckFile(PathSystem,ConfigSystem) == True:
-     Path = PathSystem
-     Config = ConfigSystem
-     message = 'INFO: Reading the CURRENT configuration from the system folder..'
-else:
-     message = 'WARNING: Unable to find any configuration file. Exiting..'
-     sys.exit(1)
+     global Path, PathSystem
+     if CheckFile(PathTheme,ConfigTheme) == True:
+         Path = PathTheme
+         Config = ConfigTheme
+     elif CheckFile(PathSystem,ConfigSystem) == True:
+         Path = PathSystem
+         Config = ConfigSystem
+     else:
+         message = 'WARNING: Unable to find any configuration file. Exiting..'
+         showMessage(message)
+         sys.exit(1)
 
-showMessage(message)
+def getCurrent():   
 
-############################################################
-               
+     if CheckFile(PathTheme,ConfigTheme) == True:
+         Path = PathTheme
+         Config = ConfigTheme
+         message = 'INFO: Reading the configuration from a theme folder..'
+         showMessage(message)
+     else:
+         Path = PathSystem
+         Config = ConfigSystem
+
+     #define variables to readout
+     global dataVars
+     dataVars={}
+     configVars = ['zoom_on_press', 'parallax', 'blurless', 'taskswitcher', 'zaxisrotation', 'forcerotation', 'tactilepopups']
+
+     #readout the variables               
+     try:
+         f = open(Path + Config, 'r')
+         string=f.read().replace(' ','')
+         f.close()
+         for line in string.splitlines():
+             line=line.split('=')
+             if line[0] in configVars:
+                 if line[1].isdigit() == False:
+                     dataVars[line[0]]=line[1]
+                 else:
+                     dataVars[line[0]]=int(line[1])
+     except IOError:
+         message = 'Reading the configuration settings gave a FATAL ERROR while loading\nConfiguration file does not exist or cannot be read.'
+         showMessage(message)
+         sys.exit(1)
+     except:
+         message = 'Reading the configuration settings gave a FATAL ERROR while loading\nSettings are corrupted.'
+         showMessage(message)
+         sys.exit(1)
+         
+             
 def doUpdateConfigSystem():            
     ''' Update the config file of the system with the edited. '''
 
@@ -186,7 +220,7 @@ class MyMainWindow(QtGui.QMainWindow):
              QtGui.QWidget.__init__(self, parent)
              self.ui = Ui_CSSUfeaturesUI()
              self.ui.setupUi(self)
-             ##self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+             #self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
              self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
              
              ##Connect the GUI Buttons with actions
@@ -200,8 +234,10 @@ class MyMainWindow(QtGui.QMainWindow):
              QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.doAbout)
              QtCore.QObject.connect(self.ui.actionRestoreDefaults, QtCore.SIGNAL('triggered()'), self.doRestoreDefaults)
              
-             ##Set current values in the GUI
-             #self.doSetCurrent()
+             ## Check which config file to use.
+             CheckConfigFile()
+             ##Set current values in the GUI.
+             self.doSetCurrent()
              
         ##Create Methods
                 
@@ -225,21 +261,22 @@ class MyMainWindow(QtGui.QMainWindow):
                  
              showMessage(message)
              
-        def doSetCurrent(self): ##FIXME: implement method!!!    
+        def doSetCurrent(self):
              ''' Set CURRENT values in the GUI''' 
-           
-             #self.ui.comboBox.setCurrentIndex(zoom_on_press)
-             #self.ui.comboBox.setCurrentIndex(parallax)
-             #self.ui.comboBox.setCurrentIndex(blurless)
-             #self.ui.comboBox.setCurrentIndex(taskswitcher)
-             #self.ui.comboBox.setCurrentIndex(zaxisrotation)
-             #self.ui.comboBox.setCurrentIndex(forcerotation)
-             #self.ui.comboBox.setCurrentIndex(tactilepopups)
+
+             #Get the values from the configuration file.
+             getCurrent()
+             #Set them in the GUI.
+             self.ui.comboBoxZoomPress.setCurrentIndex(dataVars['zoom_on_press'])
+             self.ui.comboBoxBlurless.setCurrentIndex(dataVars['blurless'])
+             self.ui.comboBoxTaskSwitcher.setCurrentIndex(dataVars['taskswitcher'])
+             self.ui.comboBoxRotationAxis.setCurrentIndex(dataVars['zaxisrotation'])
+             self.ui.comboBoxForcedRotation.setCurrentIndex(dataVars['forcerotation'])
+             self.ui.comboBoxTactile.setCurrentIndex(dataVars['tactilepopups'])
+             self.ui.lineEditParallax.setText(dataVars['parallax'])
              
-             message = 'Displaying the CURRENT configuration options feature is not yet implemented.'
-             showMessage(message)
-             # message = 'The CURRENT configuration options are shown.'
-             # showQuickMessage(message)
+             message = 'The CURRENT configuration options are shown.'
+             showQuickMessage(message)
 
         def doSetDefault(self):  
              ''' Set DEFAULT values in the GUI''' 
